# FieldOptions7

## Properties
Name | Type | Description | Notes
------------ | ------------- | ------------- | -------------
**formula** | **str** | The formula string | [optional] 
**is_valid** | **bool** | Whether the formula is valid | [optional] 
**referenced_field_ids** | **list[str]** | The ids of any fields referenced in the formula | [optional] 
**result** | **object** | The computed result of the formula | [optional] 

[[Back to Model list]](../README.md#documentation-for-models) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to README]](../README.md)

